<?php
/*
    LnBlog - A simple file-based weblog focused on design elegance.
    Copyright (C) 2005 Peter A. Geer <pageer@skepticats.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

# Class to manipulate and authenticate users.  Is designed so that a user's
# login can be checked in two lines, to keep maintenance overhead low.

require_once("lib/utils.php");
require_once("lib/lnblogobject.php");

class User extends LnBlogObject {

	var $username;
	var $passwd;
	var $salt;
	var $fullname;
	var $email;
	var $homepage;
	var $user_list;

	function User($uname=false, $pw=false) {

		if (defined("INSTALL_ROOT")) {
			if ( is_file(USER_DATA_PATH.PATH_DELIM."passwd.php") ) {
				global $global_user_list;
				$old_path = ini_get("include_path");
				ini_set("include_path", $old_path.PATH_SEPARATOR.USER_DATA_PATH);
				require_once(USER_DATA_PATH.PATH_DELIM."passwd.php");
				ini_set("include_path", $old_path);
				$this->user_list = $global_user_list;
			} else {
				$this->user_list = array();
			}
		} else $this->user_list = array();

		$this->username = '';
		$this->passwd = '';
		$this->salt = '';
		$this->fullname = '';
		$this->email = '';
		$this->homepage = '';

		if (!$uname && ( SESSION(CURRENT_USER) || COOKIE(CURRENT_USER) ) ) {
			if ( SESSION(CURRENT_USER) == COOKIE(CURRENT_USER) ||
			    (SESSION(CURRENT_USER) == '' && COOKIE(CURRENT_USER) ) 
			   ) {
				$uname = COOKIE(CURRENT_USER);
			}
		}
		if ($uname && isset($this->user_list[$uname]) ) {
			$this->username = $uname;
			$this->passwd = $this->user_list[$uname]["pwd"];
			$this->salt = $this->user_list[$uname]["salt"];
			$this->fullname = $this->user_list[$uname]["fullname"];
			$this->email = $this->user_list[$uname]["email"];
			$this->homepage = $this->user_list[$uname]["homepage"];

			if ($pw) $this->login($pw);

		}
	}

	function create_passwd_file () {
		$data = "<?php\n";
		$data .= '$global_user_list = array();'."\n";
		foreach ($this->user_list as $name=>$udat) {
			$data .= '$global_user_list[\''.$name.'\'] = array(';
			$tmpdata = '';
			foreach ($udat as $key=>$val) {
				$val = str_replace("\\", "\\\\", $val);
				$val = str_replace("'", "\\'", $val);
				$tmpdata .= ($tmpdata != '' ? ', ' : '') . "'$key'=>'$val'";
			}
			$data .= $tmpdata.");\n";
		}
		$data .= "?>";
		return write_file(USER_DATA_PATH.PATH_DELIM."passwd.php", $data);
	}


	# Convenience function to export relevant user data to a template.

	function exportVars(&$tpl) {
		if ($this->username) $tpl->set("USER_ID", $this->username);
		if ($this->fullname) $tpl->set("USER_NAME", $this->fullname);
		if ($this->email) $tpl->set("USER_EMAIL", $this->email);
		if ($this->homepage) $tpl->set("USER_HOMEPAGE", $this->homepage);
		$tpl->set("USER_DISPLAY_NAME", $this->displayName() );
	}

	function get($uname) {
		if ($uname && isset($this->user_list[$uname]) ) {
			$this->passwd = $this->user_list[$uname]["pwd"];
			$this->salt = $this->user_list[$uname]["salt"];
			$this->fullname = $this->user_list[$uname]["fullname"];
			$this->email = $this->user_list[$uname]["email"];
			$this->homepage = $this->user_list[$uname]["homepage"];
			return true;
		} else return false;
	}

	function checkPassword($pass) {
		$hash = md5($pass.$this->salt);
		$ret = ($hash == $this->passwd);
		return $ret;
	}

	# Save changes to user data.  Note that this function doesn't scale well,
	# as we cannot guarantee that the another user will not simultaneously
	# try to write the same file and clobber our changes.
	# The only real fix to this (that's worth the time to implement) is to 
	# switch to a database storage backend.

	function save() {
		if (!$this->username ||! $this->passwd) return false;
		$this->user_list[$this->username]["pwd"] = $this->passwd;
		$this->user_list[$this->username]["salt"] = $this->salt;
		$this->user_list[$this->username]["fullname"] = $this->fullname;
		$this->user_list[$this->username]["email"] = $this->email;
		$this->user_list[$this->username]["homepage"] = $this->homepage;
		$this->create_passwd_file();
	}

	function password($pwd=false) {
		if (!$pwd) return $this->passwd;
		else {
			mt_srand(time());
			# Generate a new salt
			$num_chars = mt_rand(6, 12);
			$slt = '';
			for ($i = 0; $i < $num_chars; $i++) $slt .= chr(mt_rand(65, 90));
			$this->salt = $slt;
			$this->passwd = md5($pwd.$this->salt);
			
			# Prevent password change from logging out on cookie-only config.
			if ( $this->username == COOKIE(CURRENT_USER) )
				setcookie(PW_HASH, $this->passwd);
		}
	}

	function username($uid=false) {
		if (!$uid) return $this->username;
		else $this->username = $uid;
	}

	function name($nm=false) {
		if (!$nm) return $this->fullname;
		else $this->fullname = $nm;
	}

	# Returns a name to display.  If a full name is defined, it uses that.
	# Otherwise, it reverts to the username.

	function displayName() {
		if ($this->fullname) return $this->fullname;
		else return $this->username;
	}

	function email($mail=false) {
		if (!$mail) return $this->email;
		else $this->email = $mail;
	}

	function homepage($url=false) {
		if (!$url) return $this->homepage;
		else $this->homepage = $url;
	}

	function login($pwd) {
		
		# Reject empty usernames or passwords.
		if ( trim($this->username) == "" || trim($pwd) == "" ) return false;
		
		# User does not exist.
		if ( ! isset($this->user_list[$this->username]) ) return false;

		if (AUTH_USE_SESSION) {
			$ts = gmdate("M d Y H:i:s", time());
			if ($this->checkPassword($pwd)) {
				# Create a login token.
				$token = md5(get_ip().$ts);
				setcookie(CURRENT_USER, $this->username);
				SESSION(CURRENT_USER, $this->username);
				SESSION(LOGIN_TOKEN, $token);
				SESSION(LAST_LOGIN_TIME, $ts);
				setcookie(LAST_LOGIN_TIME, "$ts");
				$ret = true;
			} else $ret = false;
			return $ret;
		} else {
			setcookie(CURRENT_USER, $this->username);
			setcookie(PW_HASH, $this->passwd);
		}
	}

	function logout() {
		if (AUTH_USE_SESSION) {
			SESSION(CURRENT_USER, false);
			SESSION(LOGIN_TOKEN, false);
			SESSION(LAST_LOGIN_TIME, false);
			setcookie(LOGIN_TOKEN, "");
			setcookie(LAST_LOGIN_TIME, "");
		} else {
			setcookie(CURRENT_USER, "");
			setcookie(PW_HASH, "");
		}
	}

	function checkLogin() {
		# If the constructor doesn't detect a user name, then we're obviously
		# not logged in.
		if (!$this->username) return false;
		if (AUTH_USE_SESSION) {
			# Check the stored login token and time against the one for the
			# current session.  Return false on failure, or if the current
			# session doesn't belong to the user we want.
			$cookie_ts = COOKIE(LAST_LOGIN_TIME);
			$auth_token = md5(get_ip().$cookie_ts);
			$auth_ok = ($auth_token == SESSION(LOGIN_TOKEN) );
			$auth_ok = $auth_ok && ($cookie_ts == SESSION(LAST_LOGIN_TIME) );
			if ($auth_ok) return true;
			else return false;
		} else {
			# Check the cookies for the user and password hash and compare to 
			# the password hash for this user on the server.
			# This is NOT secure, but it is convenient.
			$usr = COOKIE(CURRENT_USER);
			$pwhash = COOKIE(PW_HASH);
			if ($this->username == $usr && $this->passwd = $pwhash) return true;
			else return false;
		}
	}

	function isAdministrator() {
		return ($this->username == ADMIN_USER);
	}

}
?>
